==> qtjambi-network-debuginfo-macos-6.5.4.jar: sources/QtJambiNetwork/QDtlsClientVerifier_shell.h <==
#ifndef QDTLSCLIENTVERIFIER_SHELL_H
#define QDTLSCLIENTVERIFIER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtnetwork-config.h>
#if QT_CONFIG(dtls)
#include <QtNetwork/qdtls.h>
#endif //QT_CONFIG(dtls)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qudpsocket.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(dtls)

class QDtlsClientVerifier_shell : public QDtlsClientVerifier, public QtJambiShellInterface
{
public:
    QDtlsClientVerifier_shell(QObject* parent0 = nullptr);
    ~QDtlsClientVerifier_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDtlsClientVerifier_access : public QDtlsClientVerifier
{
};

#endif // QT_CONFIG(dtls)
#endif // QDTLSCLIENTVERIFIER_SHELL_H

==> qtjambi-network-debuginfo-macos-6.5.7.jar: sources/QtJambiNetwork/QDtlsClientVerifier_shell.h <==
#ifndef QDTLSCLIENTVERIFIER_SHELL_H
#define QDTLSCLIENTVERIFIER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtnetwork-config.h>
#if QT_CONFIG(dtls)
#include <QtNetwork/qdtls.h>
#endif //QT_CONFIG(dtls)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qudpsocket.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(dtls)

class QDtlsClientVerifier_shell : public QDtlsClientVerifier, public QtJambiShellInterface
{
public:
    QDtlsClientVerifier_shell(QObject* parent0 = nullptr);
    ~QDtlsClientVerifier_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QDtlsClientVerifier_mshell;
    friend class QDtlsClientVerifier_oshell;
};


class QDtlsClientVerifier_mshell : public QDtlsClientVerifier_shell
{
public:
    using QDtlsClientVerifier_shell::QDtlsClientVerifier_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QDtlsClientVerifier_oshell : public QDtlsClientVerifier_mshell
{
public:
    using QDtlsClientVerifier_mshell::QDtlsClientVerifier_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDtlsClientVerifier_access : public QDtlsClientVerifier
{
};

#endif // QT_CONFIG(dtls)
#endif // QDTLSCLIENTVERIFIER_SHELL_H
